@@ -30,6 +30,7 @@ KateViKeyParser::KateViKeyParser()
   m_katevi2qt = new QHash<QString, int>;
   m_nameToKeyCode = new QHash<QString, int>;
   m_keyCodeToName = new QHash<int, QString>;
+  m_altGrPressed = false;
 
   initKeyTables();
 }
@@ -496,7 +497,6 @@ const QString KateViKeyParser::encodeKeySequence( const QString &keys ) const
 {
   QString encodedSequence;
   unsigned int keyCodeTemp = 0;
-  int startOfBlock = -1;
 
   bool insideTag = false;
   QChar c;
@@ -574,7 +574,6 @@ const QString KateViKeyParser::encodeKeySequence( const QString &keys ) const
           encodedSequence.append( c );
           continue;
         }
-        startOfBlock = i;
         insideTag = true;
         continue;
       } else {
@@ -737,7 +736,7 @@ char KateViKeyParser::scanCodeToChar(quint32 code, Qt::KeyboardModifiers modifie
 }
 
 const QChar KateViKeyParser::KeyEventToQChar(int keyCode, const QString &text,
-    Qt::KeyboardModifiers mods, quint32 nativeScanCode) const
+    Qt::KeyboardModifiers mods, quint32 nativeScanCode)
 {
   QChar key;
 
@@ -745,6 +744,13 @@ const QChar KateViKeyParser::KeyEventToQChar(int keyCode, const QString &text,
     key = text.at(0);
   }
 
+  // If previous key press was AltGr, return key value right away and don't go
+  // down the "handle modifiers" code path. AltGr is really confusing...
+  if ( m_altGrPressed ) {
+      setAltGrStatus( false );
+      return key;
+  }
+
   if ( text.isEmpty() || ( text.length() == 1 && text.at(0) < 0x20 )
       || ( mods != Qt::NoModifier && mods != Qt::ShiftModifier ) ) {
     QString keyPress;
